@@ -22,107 +22,92 @@
  * along with MX Snapshot.  If not, see <http://www.gnu.org/licenses/>.
  **********************************************************************/
 
-#include "mainwindow.h"
-#include <unistd.h>
 #include <QApplication>
-#include <QTranslator>
-#include <QLocale>
-#include <QIcon>
-#include <QScopedPointer>
+#include <QCommandLineParser>
 #include <QDateTime>
 #include <QDebug>
+#include <QIcon>
+#include <QLibraryInfo>
+#include <QLocale>
+#include <QScopedPointer>
+#include <QTranslator>
+
+#include <unistd.h>
+#include "mainwindow.h"
+#include "version.h"
 
 static QScopedPointer<QFile> logFile;
 
 void messageHandler(QtMsgType type, const QMessageLogContext &context, const QString &msg);
-void printHelp();
 
 int main(int argc, char *argv[])
 {
-    QApplication a(argc, argv);
+    QApplication app(argc, argv);
+    app.setApplicationVersion(VERSION);
 
-    if (a.arguments().contains("--help") || a.arguments().contains("-h") ) {
-        printHelp();
-        return EXIT_SUCCESS;
-    }
-    if (a.arguments().contains("--version") || a.arguments().contains("-v") ) {
-       system("echo 'Installer version'; dpkg-query -f '${Version}' -W mx-snapshot; echo");
-       return EXIT_SUCCESS;
-    }
+    QCommandLineParser parser;
+    parser.setApplicationDescription(QObject::tr("Tool used for creating a live-CD from the running system"));
+    parser.addHelpOption();
+    parser.addVersionOption();
+    parser.addOptions({{{"k", "kernel"}, QObject::tr("Name a different kernel to use other than the default running kernel, use format returned by 'uname -r'"), "kernel-number>zzzzzzz"},
+                       {{"m", "month"}, QObject::tr("Create a montly snapshot, add 'Month' name in the ISO name, skip used space calculation")},
+                       {{"p", "preempt"}, QObject::tr("Option to fix issue with calculating checksums on preempt_rt kernels")}});
+    parser.process(app);
 
-    a.setWindowIcon(QIcon::fromTheme("mx-snapshot"));
+    app.setWindowIcon(QIcon::fromTheme(app.applicationName()));
 
     QTranslator qtTran;
-    qtTran.load(QString("qt_") + QLocale::system().name());
-    a.installTranslator(&qtTran);
+    if (qtTran.load(QLocale::system(), "qt", "_", QLibraryInfo::location(QLibraryInfo::TranslationsPath)))
+        app.installTranslator(&qtTran);
+
+    QTranslator qtBaseTran;
+    if (qtBaseTran.load("qtbase_" + QLocale::system().name(), QLibraryInfo::location(QLibraryInfo::TranslationsPath)))
+        app.installTranslator(&qtBaseTran);
 
     QTranslator appTran;
-    appTran.load(QString("mx-snapshot_") + QLocale::system().name(), "/usr/share/mx-snapshot/locale");
-    a.installTranslator(&appTran);
+    if (appTran.load(app.applicationName() + "_" + QLocale::system().name(), "/usr/share/" + app.applicationName() + "/locale"))
+        app.installTranslator(&appTran);
 
     // Check if SQUASHFS is available
     if (system("[ -f /boot/config-$(uname -r) ]") == 0 && system("grep -q ^CONFIG_SQUASHFS=[ym] /boot/config-$(uname -r)") != 0) {
-        QMessageBox::critical(nullptr, QApplication::tr("Error"),
-                QApplication::tr("Current kernel doesn't support Squashfs, cannot continue."));
+        QMessageBox::critical(nullptr, QObject::tr("Error"),
+                QObject::tr("Current kernel doesn't support Squashfs, cannot continue."));
         return EXIT_FAILURE;
     }
 
     if (getuid() == 0) {
-        QString log_name= "/var/log/mx-snapshot.log";
-        // archive old log
+        QString log_name= "/var/log/" + app.applicationName() + ".log";
         system("[ -f " + log_name.toUtf8() + " ] && mv " + log_name.toUtf8() + " " + log_name.toUtf8() + ".old");
-        // Set the logging files
         logFile.reset(new QFile(log_name));
-        // Open the file logging
         logFile.data()->open(QFile::Append | QFile::Text);
-        // Set handler
         qInstallMessageHandler(messageHandler);
 
-        MainWindow w(nullptr, a.arguments());
+        qDebug().noquote() << app.applicationName() << QObject::tr("version:") << app.applicationVersion();
+        MainWindow w(nullptr, parser);
         w.show();
-        return a.exec();
+        return app.exec();
     } else {
-        system("su-to-root -X -c " + QCoreApplication::applicationFilePath().toUtf8() + "&");
-//        QApplication::beep();
-//        QMessageBox::critical(nullptr, QApplication::tr("Error"),
-//                              QApplication::tr("You must run this program as root."));
-//        return EXIT_FAILURE;
+        system("su-to-root -X -c " + app.applicationFilePath().toUtf8() + "&");
     }
 }
 
 // The implementation of the handler
 void messageHandler(QtMsgType type, const QMessageLogContext &context, const QString &msg)
 {
-    // Write to terminal
     QTextStream term_out(stdout);
     term_out << msg << endl;
 
-    // Open stream file writes
     QTextStream out(logFile.data());
-
-    // Write the date of recording
     out << QDateTime::currentDateTime().toString("yyyy-MM-dd hh:mm:ss.zzz ");
-    // By type determine to what level belongs message
     switch (type)
     {
-    case QtInfoMsg:     out << "INF "; break;
-    case QtDebugMsg:    out << "DBG "; break;
-    case QtWarningMsg:  out << "WRN "; break;
-    case QtCriticalMsg: out << "CRT "; break;
-    case QtFatalMsg:    out << "FTL "; break;
+    case QtInfoMsg:     out << QStringLiteral("INF "); break;
+    case QtDebugMsg:    out << QStringLiteral("DBG "); break;
+    case QtWarningMsg:  out << QStringLiteral("WRN "); break;
+    case QtCriticalMsg: out << QStringLiteral("CRT "); break;
+    case QtFatalMsg:    out << QStringLiteral("FTL "); break;
     }
-    // Write to the output category of the message and the message itself
-    out << context.category << ": "
-        << msg << endl;
-    out.flush();    // Clear the buffered data
+    out << context.category << QStringLiteral(": ") << msg << endl;
 }
 
-// print CLI help info
-void printHelp()
-{
-    qDebug() << "Usage: mx-snapshot [<options>]\n";
-    qDebug() << "Options:";
-    qDebug() << "  -m --monthly Month   Create a montly snapshot, add 'Month' in the ISO name, skip used space calculation";
-    qDebug() << "  -v --version         Show version information";
-}
 
